@@ -210,6 +210,63 @@ class TestLeagueNavigator(unittest.TestCase):
         self.assertEqual(12, response[owners[0].id])
         self.assertEqual(12, response[owners[1].id])
 
+    def test_getNumberOfGamesPlayed_countMultiWeekMatchupsAsOneGameIsTrue(self):
+        owners, teamsA = getNDefaultOwnersAndTeams(2)
+        teamsB = getTeamsFromOwners(owners)
+        teamsC = getTeamsFromOwners(owners)
+        teamsD = getTeamsFromOwners(owners)
+
+        matchup1_a = Matchup(teamAId=teamsA[0].id, teamBId=teamsA[1].id, teamAScore=1, teamBScore=2)
+        matchup2_a = Matchup(teamAId=teamsA[0].id, teamBId=teamsA[1].id, teamAScore=1, teamBScore=2,
+                             matchupType=MatchupType.PLAYOFF, multiWeekMatchupId="1")
+        matchup3_a = Matchup(teamAId=teamsA[0].id, teamBId=teamsA[1].id, teamAScore=1, teamBScore=2,
+                             matchupType=MatchupType.PLAYOFF, multiWeekMatchupId="1")
+        week1_a = Week(weekNumber=1, matchups=[matchup1_a])
+        week2_a = Week(weekNumber=2, matchups=[matchup2_a])
+        week3_a = Week(weekNumber=3, matchups=[matchup3_a])
+        yearA = Year(yearNumber=2000, teams=teamsA, weeks=[week1_a, week2_a, week3_a])
+
+        matchup1_b = Matchup(teamAId=teamsB[0].id, teamBId=teamsB[1].id, teamAScore=1, teamBScore=2)
+        matchup2_b = Matchup(teamAId=teamsB[0].id, teamBId=teamsB[1].id, teamAScore=2, teamBScore=1,
+                             matchupType=MatchupType.PLAYOFF)
+        matchup3_b = Matchup(teamAId=teamsB[0].id, teamBId=teamsB[1].id, teamAScore=2, teamBScore=1,
+                             matchupType=MatchupType.CHAMPIONSHIP)
+        week1_b = Week(weekNumber=1, matchups=[matchup1_b])
+        week2_b = Week(weekNumber=2, matchups=[matchup2_b])
+        week3_b = Week(weekNumber=3, matchups=[matchup3_b])
+        yearB = Year(yearNumber=2001, teams=teamsB, weeks=[week1_b, week2_b, week3_b])
+
+        matchup1_c = Matchup(teamAId=teamsC[0].id, teamBId=teamsC[1].id, teamAScore=1, teamBScore=1)
+        matchup2_c = Matchup(teamAId=teamsC[0].id, teamBId=teamsC[1].id, teamAScore=1, teamBScore=2,
+                             matchupType=MatchupType.PLAYOFF)
+        matchup3_c = Matchup(teamAId=teamsC[0].id, teamBId=teamsC[1].id, teamAScore=1, teamBScore=2,
+                             matchupType=MatchupType.CHAMPIONSHIP)
+        week1_c = Week(weekNumber=1, matchups=[matchup1_c])
+        week2_c = Week(weekNumber=2, matchups=[matchup2_c])
+        week3_c = Week(weekNumber=3, matchups=[matchup3_c])
+        yearC = Year(yearNumber=2002, teams=teamsC, weeks=[week1_c, week2_c, week3_c])
+
+        matchup1_d = Matchup(teamAId=teamsD[0].id, teamBId=teamsD[1].id, teamAScore=1, teamBScore=2)
+        matchup2_d = Matchup(teamAId=teamsD[0].id, teamBId=teamsD[1].id, teamAScore=1, teamBScore=2,
+                             matchupType=MatchupType.PLAYOFF)
+        matchup3_d = Matchup(teamAId=teamsD[0].id, teamBId=teamsD[1].id, teamAScore=1, teamBScore=2,
+                             matchupType=MatchupType.CHAMPIONSHIP)
+        week1_d = Week(weekNumber=1, matchups=[matchup1_d])
+        week2_d = Week(weekNumber=2, matchups=[matchup2_d])
+        week3_d = Week(weekNumber=3, matchups=[matchup3_d])
+        yearD = Year(yearNumber=2003, teams=teamsD, weeks=[week1_d, week2_d, week3_d])
+
+        league = League(name="TEST", owners=owners, years=[yearA, yearB, yearC, yearD])
+
+        allTimeFilters = AllTimeFilters(yearNumberStart=2000, weekNumberStart=1, yearNumberEnd=2003, weekNumberEnd=3,
+                                        onlyChampionship=False, onlyPostSeason=False, onlyRegularSeason=False)
+        response = LeagueNavigator.getNumberOfGamesPlayed(league, allTimeFilters, countMultiWeekMatchupsAsOneGame=True)
+
+        self.assertIsInstance(response, dict)
+        self.assertEqual(2, len(response.keys()))
+        self.assertEqual(11, response[owners[0].id])
+        self.assertEqual(11, response[owners[1].id])
+
     def test_getNumberOfGamesPlayed_onlyRegularSeason(self):
         owners, teamsA = getNDefaultOwnersAndTeams(2)
         teamsB = getTeamsFromOwners(owners)
@@ -608,19 +665,29 @@ class TestLeagueNavigator(unittest.TestCase):
 
         self.assertIsInstance(response, list)
         self.assertEqual(16, len(response))
-        self.assertEqual(3, response[0])
-        self.assertEqual(4, response[1])
-        self.assertEqual(5, response[2])
-        self.assertEqual(6, response[3])
-        self.assertEqual(9, response[4])
-        self.assertEqual(10, response[5])
-        self.assertEqual(11, response[6])
-        self.assertEqual(12, response[7])
-        self.assertEqual(15, response[8])
-        self.assertEqual(16, response[9])
-        self.assertEqual(17, response[10])
-        self.assertEqual(18, response[11])
-        self.assertEqual(21, response[12])
-        self.assertEqual(22, response[13])
-        self.assertEqual(23, response[14])
-        self.assertEqual(24, response[15])
+        self.assertEqual([3, 4, 5, 6, 9, 10, 11, 12, 15, 16, 17, 18, 21, 22, 23, 24], sorted(response))
+
+    def test_getAllScoresInLeague_simplifyMultiWeekMatchupsIsTrue(self):
+        owners, teamsA = getNDefaultOwnersAndTeams(2)
+        teamsB = getTeamsFromOwners(owners)
+        teamsC = getTeamsFromOwners(owners)
+        teamsD = getTeamsFromOwners(owners)
+
+        matchup1_a = Matchup(teamAId=teamsA[0].id, teamBId=teamsA[1].id, teamAScore=1, teamBScore=2,
+                             multiWeekMatchupId="1")
+        matchup2_a = Matchup(teamAId=teamsA[0].id, teamBId=teamsA[1].id, teamAScore=3, teamBScore=4,
+                             multiWeekMatchupId="1")
+        matchup3_a = Matchup(teamAId=teamsA[0].id, teamBId=teamsA[1].id, teamAScore=5, teamBScore=6,
+                             matchupType=MatchupType.CHAMPIONSHIP)
+        week1_a = Week(weekNumber=1, matchups=[matchup1_a])
+        week2_a = Week(weekNumber=2, matchups=[matchup2_a])
+        week3_a = Week(weekNumber=3, matchups=[matchup3_a])
+        yearA = Year(yearNumber=2000, teams=teamsA, weeks=[week1_a, week2_a, week3_a])
+
+        league = League(name="TEST", owners=owners, years=[yearA])
+
+        response = LeagueNavigator.getAllScoresInLeague(league, simplifyMultiWeekMatchups=True)
+
+        self.assertIsInstance(response, list)
+        self.assertEqual(4, len(response))
+        self.assertEqual([4, 5, 6, 6], sorted(response))
